* mln/topo/face.hh (mln::topo::faces_set<N, D>): Rename as...
(mln::topo::n_faces_set<N, D>): ...this.
Adjust.
* mln/topo/complex.hh: Adjust.
---
milena/ChangeLog | 9 +++++++++
milena/mln/topo/complex.hh | 10 +++++-----
milena/mln/topo/face.hh | 30 ++++++++++++++----------------
3 files changed, 28 insertions(+), 21 deletions(-)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index ded9680..5a41910 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,5 +1,14 @@
2008-09-26 Roland Levillain <roland(a)lrde.epita.fr>
+ Rename mln::topo::faces_set as mln::topo::n_faces_set.
+
+ * mln/topo/face.hh (mln::topo::faces_set<N, D>): Rename as...
+ (mln::topo::n_faces_set<N, D>): ...this.
+ Adjust.
+ * mln/topo/complex.hh: Adjust.
+
+2008-09-26 Roland Levillain <roland(a)lrde.epita.fr>
+
Rename mln::topo::any_face_handle as mln::topo::face.
* mln/topo/face.hh (mln::topo::any_face_handle<D>): Rename as...
diff --git a/milena/mln/topo/face.hh b/milena/mln/topo/face.hh
index 85c2fef..e15c66a 100644
--- a/milena/mln/topo/face.hh
+++ b/milena/mln/topo/face.hh
@@ -39,8 +39,6 @@
/* FIXME: Suggestions:
- Rename faces_set as n_faces_set.
-
Split `face', `face_handle' and `any_face_handle' code into several
files.
@@ -48,8 +46,8 @@
hidden, either by moving it to mln/topo/complex.cc or into its own
file in mln/topo/internal.
- (And what about `faces_set'? Should we move it to its own file as
- well?) */
+ And what about `n_faces_set'? Should we move it to its own file as
+ well? */
namespace mln
{
@@ -234,7 +232,7 @@ namespace mln
/// \brief Set of face handles of dimension \p N.
template <unsigned N, unsigned D>
- class faces_set
+ class n_faces_set
{
public:
void add(const n_face<N, D>& f);
@@ -254,15 +252,15 @@ namespace mln
};
- /// Construction helpers for mln::topo::faces_set.
+ /// Construction helpers for mln::topo::n_faces_set.
/// \{
template <unsigned N, unsigned D>
- faces_set<N, D>
+ n_faces_set<N, D>
operator+(const n_face<N, D>& f1, const n_face<N, D>& f2);
template <unsigned N, unsigned D>
- faces_set<N, D>
- operator+(const faces_set<N, D>& fs, const n_face<N, D>& f);
+ n_faces_set<N, D>
+ operator+(const n_faces_set<N, D>& fs, const n_face<N, D>& f);
/// \}
@@ -536,7 +534,7 @@ namespace mln
template <unsigned N, unsigned D>
inline
void
- faces_set<N, D>::add(const n_face<N, D>& f)
+ n_faces_set<N, D>::add(const n_face<N, D>& f)
{
// Check consistency.
if (!faces_.empty())
@@ -547,7 +545,7 @@ namespace mln
template <unsigned N, unsigned D>
inline
const std::vector< n_face<N, D> >&
- faces_set<N, D>::faces() const
+ n_faces_set<N, D>::faces() const
{
return faces_;
}
@@ -555,10 +553,10 @@ namespace mln
template <unsigned N, unsigned D>
inline
- faces_set<N, D>
+ n_faces_set<N, D>
operator+(const n_face<N, D>& f1, const n_face<N, D>& f2)
{
- faces_set<N, D> fs;
+ n_faces_set<N, D> fs;
fs.add(f1);
fs.add(f2);
return fs;
@@ -566,10 +564,10 @@ namespace mln
template <unsigned N, unsigned D>
inline
- faces_set<N, D>
- operator+(const faces_set<N, D>& fs, const n_face<N, D>& f)
+ n_faces_set<N, D>
+ operator+(const n_faces_set<N, D>& fs, const n_face<N, D>& f)
{
- faces_set<N, D> fs2(fs);
+ n_faces_set<N, D> fs2(fs);
fs2.add(f);
return fs2;
}
diff --git a/milena/mln/topo/complex.hh b/milena/mln/topo/complex.hh
index de6fb90..3ed8923 100644
--- a/milena/mln/topo/complex.hh
+++ b/milena/mln/topo/complex.hh
@@ -105,7 +105,7 @@ namespace mln
/// \param adjacent_faces The (\p N-1)-faces adjacent to the new
/// \p N-face.
template <unsigned N>
- n_face<N + 1, D> add_face(const faces_set<N, D>& adjacent_faces);
+ n_face<N + 1, D> add_face(const n_faces_set<N, D>&
adjacent_faces);
/// \}
/// \brief Static manipulators.
@@ -128,8 +128,8 @@ namespace mln
/// \brief Return the number of \a n-faces.
///
/// Warning, this function has a complexity linear in term of N,
/// since each faces_set is checked (the present implementation
/// does not provide a direct access to faces_set through a
/// dynamic value of the dimension).
std::size_t nfaces(unsigned n) const;
/// \}
@@ -171,7 +171,7 @@ namespace mln
/* FIXME: Replace F and ACCU by a Milena accumulator? */
/** \brief Apply a kind of static fold left operator to the
- implicit list of faces_set using a functor \a f and a value \a
+ implicit list of n_faces_set using a functor \a f and a value \a
accu.
Argument \a is called an "accumulator", but with a slightly
@@ -420,7 +420,7 @@ namespace mln
template <unsigned D>
template <unsigned N>
n_face<N + 1, D>
- complex<D>::add_face(const faces_set<N, D>& adjacent_faces)
+ complex<D>::add_face(const n_faces_set<N, D>& adjacent_faces)
{
typedef typename std::vector< n_face<N, D> >::const_iterator iter_t;
@@ -128,8 +128,8 @@ namespace mln
///
/// Warning, this function has a complexity linear in term of N,
- /// since each faces_set is checked (the present implementation
- /// does not provide a direct access to faces_set through a
+ /// since each n_faces_set is checked (the present implementation
+ /// does not provide a direct access to n_faces_set through a
/// dynamic value of the dimension).
std::size_t nfaces(unsigned n) const;
--
1.6.0.1